# korona_client

KoronaClient - the Ruby gem for the KORONA.cloud API v3

Our api provides access to our cloud services

This SDK is automatically generated by the [Swagger Codegen](https://github.com/swagger-api/swagger-codegen) project:

- API version: 2.11.21
- Package version: 1.1.0
- Build package: io.swagger.codegen.languages.RubyClientCodegen

## Installation

### Build a gem

To build the Ruby code into a gem:

```shell
gem build korona_client.gemspec
```

Then either install the gem locally:

```shell
gem install ./korona_client-1.1.0.gem
```
(for development, run `gem install --dev ./korona_client-1.1.0.gem` to install the development dependencies)

or publish the gem to a gem hosting service, e.g. [RubyGems](https://rubygems.org/).

Finally add this to the Gemfile:

    gem 'korona_client', '~> 1.1.0'

### Install from Git

If the Ruby gem is hosted at a git repository: https://github.com/GIT_USER_ID/GIT_REPO_ID, then add the following in the Gemfile:

    gem 'korona_client', :git => 'https://github.com/GIT_USER_ID/GIT_REPO_ID.git'

### Include the Ruby code directly

Include the Ruby code directly using `-I` as follows:

```shell
ruby -Ilib script.rb
```

## Getting Started

Please follow the [installation](#installation) procedure and then run the following code:
```ruby
# Load the gem
require 'korona_client'

# Setup authorization
KoronaClient.configure do |config|
  # Configure HTTP basic authorization: basicAuth
  config.username = 'YOUR USERNAME'
  config.password = 'YOUR PASSWORD'
end

api_instance = KoronaClient::AccountsApi.new

korona_account_id = 'korona_account_id_example' # String | account id of the KORONA.cloud account

account_id = 'account_id_example' # String | id of the related object (important: id should match the uuid-format)


begin
  #returns the single account
  result = api_instance.get_account(korona_account_id, account_id)
  p result
rescue KoronaClient::ApiError => e
  puts "Exception when calling AccountsApi->get_account: #{e}"
end

```

## Documentation for API Endpoints

All URIs are relative to *https://www.koronacloud.com/web/api/v3*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*KoronaClient::AccountsApi* | [**get_account**](docs/AccountsApi.md#get_account) | **GET** /accounts/{koronaAccountId}/accounts/{accountId} | returns the single account
*KoronaClient::AccountsApi* | [**get_accounts**](docs/AccountsApi.md#get_accounts) | **GET** /accounts/{koronaAccountId}/accounts | lists all accounts
*KoronaClient::AdditionalReceiptInfoTypesApi* | [**get_additional_receipt_info_type**](docs/AdditionalReceiptInfoTypesApi.md#get_additional_receipt_info_type) | **GET** /accounts/{koronaAccountId}/additionalReceiptInfoTypes/{additionalReceiptInfoTypeId} | returns the single additional receipt info type
*KoronaClient::AdditionalReceiptInfoTypesApi* | [**get_additional_receipt_info_types**](docs/AdditionalReceiptInfoTypesApi.md#get_additional_receipt_info_types) | **GET** /accounts/{koronaAccountId}/additionalReceiptInfoTypes | lists all additional receipt info types
*KoronaClient::AssortmentsApi* | [**add_assortments**](docs/AssortmentsApi.md#add_assortments) | **POST** /accounts/{koronaAccountId}/assortments | adds a batch of new assortments
*KoronaClient::AssortmentsApi* | [**delete_assortment**](docs/AssortmentsApi.md#delete_assortment) | **DELETE** /accounts/{koronaAccountId}/assortments/{assortmentId} | deletes the single assortment
*KoronaClient::AssortmentsApi* | [**delete_assortments**](docs/AssortmentsApi.md#delete_assortments) | **DELETE** /accounts/{koronaAccountId}/assortments | deletes a batch of assortments
*KoronaClient::AssortmentsApi* | [**get_assortment**](docs/AssortmentsApi.md#get_assortment) | **GET** /accounts/{koronaAccountId}/assortments/{assortmentId} | returns the single assortment
*KoronaClient::AssortmentsApi* | [**get_assortments**](docs/AssortmentsApi.md#get_assortments) | **GET** /accounts/{koronaAccountId}/assortments | lists all assortments
*KoronaClient::AssortmentsApi* | [**update_assortment**](docs/AssortmentsApi.md#update_assortment) | **PATCH** /accounts/{koronaAccountId}/assortments/{assortmentId} | updates the single assortment
*KoronaClient::AssortmentsApi* | [**update_assortments**](docs/AssortmentsApi.md#update_assortments) | **PATCH** /accounts/{koronaAccountId}/assortments | updates a batch of assortments
*KoronaClient::CashiersApi* | [**get_cashier**](docs/CashiersApi.md#get_cashier) | **GET** /accounts/{koronaAccountId}/cashiers/{cashierId} | returns the single cashier
*KoronaClient::CashiersApi* | [**get_cashiers**](docs/CashiersApi.md#get_cashiers) | **GET** /accounts/{koronaAccountId}/cashiers | lists all cashiers
*KoronaClient::CommodityGroupsApi* | [**add_commodity_groups**](docs/CommodityGroupsApi.md#add_commodity_groups) | **POST** /accounts/{koronaAccountId}/commodityGroups | adds a batch of new commodity groups
*KoronaClient::CommodityGroupsApi* | [**delete_commodity_group**](docs/CommodityGroupsApi.md#delete_commodity_group) | **DELETE** /accounts/{koronaAccountId}/commodityGroups/{commodityGroupId} | deletes the single commodity group
*KoronaClient::CommodityGroupsApi* | [**delete_commodity_groups**](docs/CommodityGroupsApi.md#delete_commodity_groups) | **DELETE** /accounts/{koronaAccountId}/commodityGroups | deletes a batch of commodity groups
*KoronaClient::CommodityGroupsApi* | [**get_commodity_group**](docs/CommodityGroupsApi.md#get_commodity_group) | **GET** /accounts/{koronaAccountId}/commodityGroups/{commodityGroupId} | returns the single commodity group
*KoronaClient::CommodityGroupsApi* | [**get_commodity_groups**](docs/CommodityGroupsApi.md#get_commodity_groups) | **GET** /accounts/{koronaAccountId}/commodityGroups | lists all commodity groups
*KoronaClient::CommodityGroupsApi* | [**update_commodity_group**](docs/CommodityGroupsApi.md#update_commodity_group) | **PATCH** /accounts/{koronaAccountId}/commodityGroups/{commodityGroupId} | updates the single commodity group
*KoronaClient::CommodityGroupsApi* | [**update_commodity_groups**](docs/CommodityGroupsApi.md#update_commodity_groups) | **PATCH** /accounts/{koronaAccountId}/commodityGroups | updates a batch of commodity groups
*KoronaClient::CurrenciesApi* | [**get_currencies**](docs/CurrenciesApi.md#get_currencies) | **GET** /accounts/{koronaAccountId}/currencies | lists all currencies
*KoronaClient::CurrenciesApi* | [**get_currency**](docs/CurrenciesApi.md#get_currency) | **GET** /accounts/{koronaAccountId}/currencies/{currencyId} | returns the single currency
*KoronaClient::CustomerGroupsApi* | [**get_customer_group**](docs/CustomerGroupsApi.md#get_customer_group) | **GET** /accounts/{koronaAccountId}/customerGroups/{customerGroupId} | returns the single customer group
*KoronaClient::CustomerGroupsApi* | [**get_customer_groups**](docs/CustomerGroupsApi.md#get_customer_groups) | **GET** /accounts/{koronaAccountId}/customerGroups | lists all customer groups
*KoronaClient::CustomerOrdersApi* | [**add_customer_orders**](docs/CustomerOrdersApi.md#add_customer_orders) | **POST** /accounts/{koronaAccountId}/customerOrders | adds a batch of new customer orders
*KoronaClient::CustomerOrdersApi* | [**delete_customer_order**](docs/CustomerOrdersApi.md#delete_customer_order) | **DELETE** /accounts/{koronaAccountId}/customerOrders/{customerOrderId} | deletes the single customer order
*KoronaClient::CustomerOrdersApi* | [**get_customer_order**](docs/CustomerOrdersApi.md#get_customer_order) | **GET** /accounts/{koronaAccountId}/customerOrders/{customerOrderId} | returns the single customer order
*KoronaClient::CustomerOrdersApi* | [**get_customer_orders**](docs/CustomerOrdersApi.md#get_customer_orders) | **GET** /accounts/{koronaAccountId}/customerOrders | lists all customer orders
*KoronaClient::CustomerOrdersApi* | [**update_customer_order**](docs/CustomerOrdersApi.md#update_customer_order) | **PATCH** /accounts/{koronaAccountId}/customerOrders/{customerOrderId} | updates the single customer order
*KoronaClient::CustomerOrdersApi* | [**update_customer_orders**](docs/CustomerOrdersApi.md#update_customer_orders) | **PATCH** /accounts/{koronaAccountId}/customerOrders | updates a batch of customer orders
*KoronaClient::CustomersApi* | [**add_customers**](docs/CustomersApi.md#add_customers) | **POST** /accounts/{koronaAccountId}/customers | adds a batch of new customers
*KoronaClient::CustomersApi* | [**delete_customer**](docs/CustomersApi.md#delete_customer) | **DELETE** /accounts/{koronaAccountId}/customers/{customerId} | deletes the single customer
*KoronaClient::CustomersApi* | [**delete_customers**](docs/CustomersApi.md#delete_customers) | **DELETE** /accounts/{koronaAccountId}/customers | deletes a batch of customers
*KoronaClient::CustomersApi* | [**get_customer**](docs/CustomersApi.md#get_customer) | **GET** /accounts/{koronaAccountId}/customers/{customerId} | returns the single customer
*KoronaClient::CustomersApi* | [**get_customers**](docs/CustomersApi.md#get_customers) | **GET** /accounts/{koronaAccountId}/customers | lists all customers
*KoronaClient::CustomersApi* | [**update_customer**](docs/CustomersApi.md#update_customer) | **PATCH** /accounts/{koronaAccountId}/customers/{customerId} | updates the single customer
*KoronaClient::CustomersApi* | [**update_customers**](docs/CustomersApi.md#update_customers) | **PATCH** /accounts/{koronaAccountId}/customers | updates a batch of customers
*KoronaClient::DeliveryNotesApi* | [**add_delivery_notes**](docs/DeliveryNotesApi.md#add_delivery_notes) | **POST** /accounts/{koronaAccountId}/deliveryNotes | adds delivery notes
*KoronaClient::DeliveryNotesApi* | [**book_delivery_note**](docs/DeliveryNotesApi.md#book_delivery_note) | **PATCH** /accounts/{koronaAccountId}/deliveryNotes/{deliveryNoteId}/book | book the single delivery note
*KoronaClient::DeliveryNotesApi* | [**finalize_delivery_note**](docs/DeliveryNotesApi.md#finalize_delivery_note) | **PATCH** /accounts/{koronaAccountId}/deliveryNotes/{deliveryNoteId}/finalize | finalize the single delivery note
*KoronaClient::DeliveryNotesApi* | [**get_delivery_note**](docs/DeliveryNotesApi.md#get_delivery_note) | **GET** /accounts/{koronaAccountId}/deliveryNotes/{deliveryNoteId} | returns a single delivery note
*KoronaClient::DeliveryNotesApi* | [**get_delivery_notes**](docs/DeliveryNotesApi.md#get_delivery_notes) | **GET** /accounts/{koronaAccountId}/deliveryNotes | lists all delivery notes
*KoronaClient::EconomicZonesApi* | [**get_economic_zone**](docs/EconomicZonesApi.md#get_economic_zone) | **GET** /accounts/{koronaAccountId}/economicZones/{economicZoneId} | returns the single economic zone
*KoronaClient::EconomicZonesApi* | [**get_economic_zones**](docs/EconomicZonesApi.md#get_economic_zones) | **GET** /accounts/{koronaAccountId}/economicZones | lists all economic zones
*KoronaClient::ExternalSystemCallsApi* | [**add_external_system_calls**](docs/ExternalSystemCallsApi.md#add_external_system_calls) | **POST** /accounts/{koronaAccountId}/externalSystemCalls | adds a batch of new external system calls
*KoronaClient::ExternalSystemCallsApi* | [**delete_external_system_call**](docs/ExternalSystemCallsApi.md#delete_external_system_call) | **DELETE** /accounts/{koronaAccountId}/externalSystemCalls/{externalSystemCallId} | deletes a single external system call
*KoronaClient::ExternalSystemCallsApi* | [**delete_external_system_calls**](docs/ExternalSystemCallsApi.md#delete_external_system_calls) | **DELETE** /accounts/{koronaAccountId}/externalSystemCalls | deletes a batch of external system calls
*KoronaClient::ExternalSystemCallsApi* | [**get_external_system_call**](docs/ExternalSystemCallsApi.md#get_external_system_call) | **GET** /accounts/{koronaAccountId}/externalSystemCalls/{externalSystemCallId} | returns a single external system call
*KoronaClient::ExternalSystemCallsApi* | [**get_external_system_calls**](docs/ExternalSystemCallsApi.md#get_external_system_calls) | **GET** /accounts/{koronaAccountId}/externalSystemCalls | lists all external system calls
*KoronaClient::ExternalSystemCallsApi* | [**update_external_system_call**](docs/ExternalSystemCallsApi.md#update_external_system_call) | **PATCH** /accounts/{koronaAccountId}/externalSystemCalls/{externalSystemCallId} | updates the single external system call
*KoronaClient::ExternalSystemCallsApi* | [**update_external_system_calls**](docs/ExternalSystemCallsApi.md#update_external_system_calls) | **PATCH** /accounts/{koronaAccountId}/externalSystemCalls | updates a batch of external system calls
*KoronaClient::ImagesApi* | [**get_image**](docs/ImagesApi.md#get_image) | **GET** /accounts/{koronaAccountId}/images/{imageId} | displays the image
*KoronaClient::InfoTextsApi* | [**get_info_text**](docs/InfoTextsApi.md#get_info_text) | **GET** /accounts/{koronaAccountId}/infoTexts/{infoTextId} | returns the single info text
*KoronaClient::InfoTextsApi* | [**get_info_texts**](docs/InfoTextsApi.md#get_info_texts) | **GET** /accounts/{koronaAccountId}/infoTexts | lists all info texts
*KoronaClient::InventoriesApi* | [**add_inventories**](docs/InventoriesApi.md#add_inventories) | **POST** /accounts/{koronaAccountId}/inventories | adds a batch of new inventories
*KoronaClient::InventoriesApi* | [**add_inventory_inventory_list_items**](docs/InventoriesApi.md#add_inventory_inventory_list_items) | **POST** /accounts/{koronaAccountId}/inventories/{inventoryId}/inventoryLists/{inventoryListId}/items | adds inventory list items
*KoronaClient::InventoriesApi* | [**delete_inventory**](docs/InventoriesApi.md#delete_inventory) | **DELETE** /accounts/{koronaAccountId}/inventories/{inventoryId} | deletes the single inventory (only allowed if hasBookedReceipts=false)
*KoronaClient::InventoriesApi* | [**delete_inventory_inventory_list_item**](docs/InventoriesApi.md#delete_inventory_inventory_list_item) | **DELETE** /accounts/{koronaAccountId}/inventories/{inventoryId}/inventoryLists/{inventoryListId}/items/{productId} | deletes the single inventory list item
*KoronaClient::InventoriesApi* | [**get_inventories**](docs/InventoriesApi.md#get_inventories) | **GET** /accounts/{koronaAccountId}/inventories | lists all inventories
*KoronaClient::InventoriesApi* | [**get_inventory**](docs/InventoriesApi.md#get_inventory) | **GET** /accounts/{koronaAccountId}/inventories/{inventoryId} | returns the single inventory
*KoronaClient::InventoriesApi* | [**get_inventory_inventory_list**](docs/InventoriesApi.md#get_inventory_inventory_list) | **GET** /accounts/{koronaAccountId}/inventories/{inventoryId}/inventoryLists/{inventoryListId} | returns the single inventory list
*KoronaClient::InventoriesApi* | [**get_inventory_inventory_list_item**](docs/InventoriesApi.md#get_inventory_inventory_list_item) | **GET** /accounts/{koronaAccountId}/inventories/{inventoryId}/inventoryLists/{inventoryListId}/items/{productId} | returns the single inventory list item
*KoronaClient::InventoriesApi* | [**get_inventory_inventory_list_items**](docs/InventoriesApi.md#get_inventory_inventory_list_items) | **GET** /accounts/{koronaAccountId}/inventories/{inventoryId}/inventoryLists/{inventoryListId}/items | lists all inventory list items
*KoronaClient::InventoriesApi* | [**get_inventory_inventory_lists**](docs/InventoriesApi.md#get_inventory_inventory_lists) | **GET** /accounts/{koronaAccountId}/inventories/{inventoryId}/inventoryLists | lists all inventory lists
*KoronaClient::InventoriesApi* | [**update_inventory**](docs/InventoriesApi.md#update_inventory) | **PATCH** /accounts/{koronaAccountId}/inventories/{inventoryId} | updates the single inventory
*KoronaClient::InventoriesApi* | [**update_inventory_inventory_list**](docs/InventoriesApi.md#update_inventory_inventory_list) | **PATCH** /accounts/{koronaAccountId}/inventories/{inventoryId}/inventoryLists/{inventoryListId} | updates the single inventory list
*KoronaClient::InventoriesApi* | [**update_inventory_inventory_list_item**](docs/InventoriesApi.md#update_inventory_inventory_list_item) | **PATCH** /accounts/{koronaAccountId}/inventories/{inventoryId}/inventoryLists/{inventoryListId}/items/{productId} | updates the single inventory list item
*KoronaClient::InventoriesApi* | [**update_inventory_inventory_list_items**](docs/InventoriesApi.md#update_inventory_inventory_list_items) | **PATCH** /accounts/{koronaAccountId}/inventories/{inventoryId}/inventoryLists/{inventoryListId}/items | updates inventory list items (property [product] required))
*KoronaClient::KoronaAccountApi* | [**get_korona_account**](docs/KoronaAccountApi.md#get_korona_account) | **GET** /accounts/{koronaAccountId} | returns the single korona account
*KoronaClient::OrganizationalUnitsApi* | [**add_organizational_unit_day_ratings**](docs/OrganizationalUnitsApi.md#add_organizational_unit_day_ratings) | **POST** /accounts/{koronaAccountId}/organizationalUnits/{organizationalUnitId}/dayRatings | adds a batch of new day ratings
*KoronaClient::OrganizationalUnitsApi* | [**delete_organizational_unit_day_rating**](docs/OrganizationalUnitsApi.md#delete_organizational_unit_day_rating) | **DELETE** /accounts/{koronaAccountId}/organizationalUnits/{organizationalUnitId}/dayRatings/{dayRatingIdOrDate} | deletes the single day rating by its id or date
*KoronaClient::OrganizationalUnitsApi* | [**get_organizational_unit**](docs/OrganizationalUnitsApi.md#get_organizational_unit) | **GET** /accounts/{koronaAccountId}/organizationalUnits/{organizationalUnitId} | returns the single organizational unit
*KoronaClient::OrganizationalUnitsApi* | [**get_organizational_unit_day_rating**](docs/OrganizationalUnitsApi.md#get_organizational_unit_day_rating) | **GET** /accounts/{koronaAccountId}/organizationalUnits/{organizationalUnitId}/dayRatings/{dayRatingIdOrDate} | returns the single day rating by its id or date
*KoronaClient::OrganizationalUnitsApi* | [**get_organizational_unit_day_ratings**](docs/OrganizationalUnitsApi.md#get_organizational_unit_day_ratings) | **GET** /accounts/{koronaAccountId}/organizationalUnits/{organizationalUnitId}/dayRatings | lists all organizational unit related day ratings
*KoronaClient::OrganizationalUnitsApi* | [**get_organizational_unit_inventory_lists**](docs/OrganizationalUnitsApi.md#get_organizational_unit_inventory_lists) | **GET** /accounts/{koronaAccountId}/organizationalUnits/{organizationalUnitId}/inventoryLists | lists the inventory lists belonging to the organizational unit (KORONA.retail required)
*KoronaClient::OrganizationalUnitsApi* | [**get_organizational_unit_product_stocks**](docs/OrganizationalUnitsApi.md#get_organizational_unit_product_stocks) | **GET** /accounts/{koronaAccountId}/organizationalUnits/{organizationalUnitId}/productStocks | lists the product stocks of the organizational unit, in case it contains a warehouse (KORONA.retail required)
*KoronaClient::OrganizationalUnitsApi* | [**get_organizational_unit_stock_receipts**](docs/OrganizationalUnitsApi.md#get_organizational_unit_stock_receipts) | **GET** /accounts/{koronaAccountId}/organizationalUnits/{organizationalUnitId}/stockReceipts | lists the stock receipts belonging to the organizational unit (KORONA.retail required)
*KoronaClient::OrganizationalUnitsApi* | [**get_organizational_units**](docs/OrganizationalUnitsApi.md#get_organizational_units) | **GET** /accounts/{koronaAccountId}/organizationalUnits | lists all organizational units
*KoronaClient::OrganizationalUnitsApi* | [**update_organizational_unit_day_rating**](docs/OrganizationalUnitsApi.md#update_organizational_unit_day_rating) | **PATCH** /accounts/{koronaAccountId}/organizationalUnits/{organizationalUnitId}/dayRatings/{dayRatingIdOrDate} | updates the day rating by its id or date
*KoronaClient::OrganizationalUnitsApi* | [**update_organizational_unit_day_ratings**](docs/OrganizationalUnitsApi.md#update_organizational_unit_day_ratings) | **PATCH** /accounts/{koronaAccountId}/organizationalUnits/{organizationalUnitId}/dayRatings | updates a batch of day ratings
*KoronaClient::PaymentMethodsApi* | [**get_payment_method**](docs/PaymentMethodsApi.md#get_payment_method) | **GET** /accounts/{koronaAccountId}/paymentMethods/{paymentMethodId} | returns the single payment method
*KoronaClient::PaymentMethodsApi* | [**get_payment_methods**](docs/PaymentMethodsApi.md#get_payment_methods) | **GET** /accounts/{koronaAccountId}/paymentMethods | lists all payment methods
*KoronaClient::PointsOfSaleApi* | [**add_point_of_sale_end_of_day_statements**](docs/PointsOfSaleApi.md#add_point_of_sale_end_of_day_statements) | **POST** /accounts/{koronaAccountId}/pointsOfSale/{pointOfSaleId}/endOfDayStatements | adds a batch of point of sale-related end-of-day-statements
*KoronaClient::PointsOfSaleApi* | [**add_point_of_sale_receipts**](docs/PointsOfSaleApi.md#add_point_of_sale_receipts) | **POST** /accounts/{koronaAccountId}/pointsOfSale/{pointOfSaleId}/receipts | adds a batch of point of sale-related receipts
*KoronaClient::PointsOfSaleApi* | [**get_point_of_sale**](docs/PointsOfSaleApi.md#get_point_of_sale) | **GET** /accounts/{koronaAccountId}/pointsOfSale/{pointOfSaleId} | returns the single point of sale
*KoronaClient::PointsOfSaleApi* | [**get_point_of_sale_end_of_day_statements**](docs/PointsOfSaleApi.md#get_point_of_sale_end_of_day_statements) | **GET** /accounts/{koronaAccountId}/pointsOfSale/{pointOfSaleId}/endOfDayStatements | lists all point of sale-related end-of-day-statements
*KoronaClient::PointsOfSaleApi* | [**get_point_of_sale_receipt**](docs/PointsOfSaleApi.md#get_point_of_sale_receipt) | **GET** /accounts/{koronaAccountId}/pointsOfSale/{pointOfSaleId}/receipts/{receiptId} | returns the single point of sale-related receipt
*KoronaClient::PointsOfSaleApi* | [**get_point_of_sale_receipts**](docs/PointsOfSaleApi.md#get_point_of_sale_receipts) | **GET** /accounts/{koronaAccountId}/pointsOfSale/{pointOfSaleId}/receipts | lists all point of sale-related receipts
*KoronaClient::PointsOfSaleApi* | [**get_points_of_sale**](docs/PointsOfSaleApi.md#get_points_of_sale) | **GET** /accounts/{koronaAccountId}/pointsOfSale | lists all points of sale
*KoronaClient::PointsOfSaleApi* | [**update_point_of_sale**](docs/PointsOfSaleApi.md#update_point_of_sale) | **PATCH** /accounts/{koronaAccountId}/pointsOfSale/{pointOfSaleId} | updates a point of sale (works only for coupling (attribute 'couplingId') or updating device information (attribute 'deviceInformation'))
*KoronaClient::PriceGroupsApi* | [**get_price_group**](docs/PriceGroupsApi.md#get_price_group) | **GET** /accounts/{koronaAccountId}/priceGroups/{priceGroupId} | returns the single price group
*KoronaClient::PriceGroupsApi* | [**get_price_groups**](docs/PriceGroupsApi.md#get_price_groups) | **GET** /accounts/{koronaAccountId}/priceGroups | lists all price groups
*KoronaClient::ProductsApi* | [**add_products**](docs/ProductsApi.md#add_products) | **POST** /accounts/{koronaAccountId}/products | adds a batch of new products
*KoronaClient::ProductsApi* | [**delete_product**](docs/ProductsApi.md#delete_product) | **DELETE** /accounts/{koronaAccountId}/products/{productId} | deletes the single product
*KoronaClient::ProductsApi* | [**delete_products**](docs/ProductsApi.md#delete_products) | **DELETE** /accounts/{koronaAccountId}/products | deletes a batch of products
*KoronaClient::ProductsApi* | [**get_product**](docs/ProductsApi.md#get_product) | **GET** /accounts/{koronaAccountId}/products/{productId} | returns the single product
*KoronaClient::ProductsApi* | [**get_product_stocks**](docs/ProductsApi.md#get_product_stocks) | **GET** /accounts/{koronaAccountId}/products/{productId}/stocks | lists the product stocks in different warehouses (KORONA.retail required)
*KoronaClient::ProductsApi* | [**get_products**](docs/ProductsApi.md#get_products) | **GET** /accounts/{koronaAccountId}/products | lists all products
*KoronaClient::ProductsApi* | [**update_product**](docs/ProductsApi.md#update_product) | **PATCH** /accounts/{koronaAccountId}/products/{productId} | updates the single product
*KoronaClient::ProductsApi* | [**update_products**](docs/ProductsApi.md#update_products) | **PATCH** /accounts/{koronaAccountId}/products | updates a batch of products
*KoronaClient::ReceiptsApi* | [**get_receipt**](docs/ReceiptsApi.md#get_receipt) | **GET** /accounts/{koronaAccountId}/receipts/{receiptId} | returns the single receipt
*KoronaClient::ReceiptsApi* | [**get_receipts**](docs/ReceiptsApi.md#get_receipts) | **GET** /accounts/{koronaAccountId}/receipts | lists all receipts
*KoronaClient::SalesTaxesApi* | [**get_sales_tax**](docs/SalesTaxesApi.md#get_sales_tax) | **GET** /accounts/{koronaAccountId}/salesTaxes/{salesTaxId} | returns the single sales tax
*KoronaClient::SalesTaxesApi* | [**get_sales_taxes**](docs/SalesTaxesApi.md#get_sales_taxes) | **GET** /accounts/{koronaAccountId}/salesTaxes | lists all sales taxes
*KoronaClient::SectorsApi* | [**get_sector**](docs/SectorsApi.md#get_sector) | **GET** /accounts/{koronaAccountId}/sectors/{sectorId} | returns the single sector
*KoronaClient::SectorsApi* | [**get_sectors**](docs/SectorsApi.md#get_sectors) | **GET** /accounts/{koronaAccountId}/sectors | lists all sectors
*KoronaClient::StatisticsApi* | [**get_revenue**](docs/StatisticsApi.md#get_revenue) | **GET** /accounts/{koronaAccountId}/statistics/revenueData | returns information about the revenue in the given period
*KoronaClient::StatisticsApi* | [**get_revenue_for_customer_groups**](docs/StatisticsApi.md#get_revenue_for_customer_groups) | **GET** /accounts/{koronaAccountId}/statistics/revenueDataForCustomerGroups | returns the turnover per customer group during the given period
*KoronaClient::StatisticsApi* | [**get_revenue_hourly**](docs/StatisticsApi.md#get_revenue_hourly) | **GET** /accounts/{koronaAccountId}/statistics/revenueDataHourly | returns the turnover per hour during the given period
*KoronaClient::StatisticsApi* | [**get_top_seller**](docs/StatisticsApi.md#get_top_seller) | **GET** /accounts/{koronaAccountId}/statistics/topSeller | returns the top-seller
*KoronaClient::StockReceiptsApi* | [**add_stock_receipt_items**](docs/StockReceiptsApi.md#add_stock_receipt_items) | **POST** /accounts/{koronaAccountId}/stockReceipts/{stockReceiptId}/items | adds stock-receipt items
*KoronaClient::StockReceiptsApi* | [**add_stock_receipts**](docs/StockReceiptsApi.md#add_stock_receipts) | **POST** /accounts/{koronaAccountId}/stockReceipts | adds stock-receipts
*KoronaClient::StockReceiptsApi* | [**book_stock_receipt**](docs/StockReceiptsApi.md#book_stock_receipt) | **PATCH** /accounts/{koronaAccountId}/stockReceipts/{stockReceiptId}/book | book the single stock-receipt
*KoronaClient::StockReceiptsApi* | [**delete_stock_receipt_item**](docs/StockReceiptsApi.md#delete_stock_receipt_item) | **DELETE** /accounts/{koronaAccountId}/stockReceipts/{stockReceiptId}/items/{productId} | deletes the single stock-receipt item
*KoronaClient::StockReceiptsApi* | [**get_stock_receipt**](docs/StockReceiptsApi.md#get_stock_receipt) | **GET** /accounts/{koronaAccountId}/stockReceipts/{stockReceiptId} | returns the single stock-receipt
*KoronaClient::StockReceiptsApi* | [**get_stock_receipt_item**](docs/StockReceiptsApi.md#get_stock_receipt_item) | **GET** /accounts/{koronaAccountId}/stockReceipts/{stockReceiptId}/items/{productId} | returns the single stock-receipt item
*KoronaClient::StockReceiptsApi* | [**get_stock_receipt_items**](docs/StockReceiptsApi.md#get_stock_receipt_items) | **GET** /accounts/{koronaAccountId}/stockReceipts/{stockReceiptId}/items | lists all stock-receipt items
*KoronaClient::StockReceiptsApi* | [**get_stock_receipts**](docs/StockReceiptsApi.md#get_stock_receipts) | **GET** /accounts/{koronaAccountId}/stockReceipts | lists all stock-receipts
*KoronaClient::StockReceiptsApi* | [**update_stock_receipt**](docs/StockReceiptsApi.md#update_stock_receipt) | **PATCH** /accounts/{koronaAccountId}/stockReceipts/{stockReceiptId} | updates the single stock-receipt
*KoronaClient::StockReceiptsApi* | [**update_stock_receipt_item**](docs/StockReceiptsApi.md#update_stock_receipt_item) | **PATCH** /accounts/{koronaAccountId}/stockReceipts/{stockReceiptId}/items/{productId} | updates the single stock-receipt item
*KoronaClient::StockReceiptsApi* | [**update_stock_receipt_items**](docs/StockReceiptsApi.md#update_stock_receipt_items) | **PATCH** /accounts/{koronaAccountId}/stockReceipts/{stockReceiptId}/items | updates stock-receipt items
*KoronaClient::SuppliersApi* | [**get_supplier**](docs/SuppliersApi.md#get_supplier) | **GET** /accounts/{koronaAccountId}/suppliers/{supplierId} | returns the single supplier
*KoronaClient::SuppliersApi* | [**get_suppliers**](docs/SuppliersApi.md#get_suppliers) | **GET** /accounts/{koronaAccountId}/suppliers | lists all suppliers
*KoronaClient::TagsApi* | [**add_tags**](docs/TagsApi.md#add_tags) | **POST** /accounts/{koronaAccountId}/tags | adds a batch of new tags
*KoronaClient::TagsApi* | [**delete_tag**](docs/TagsApi.md#delete_tag) | **DELETE** /accounts/{koronaAccountId}/tags/{tagId} | deletes the single tag
*KoronaClient::TagsApi* | [**delete_tags**](docs/TagsApi.md#delete_tags) | **DELETE** /accounts/{koronaAccountId}/tags | deletes a batch of tags
*KoronaClient::TagsApi* | [**get_tag**](docs/TagsApi.md#get_tag) | **GET** /accounts/{koronaAccountId}/tags/{tagId} | returns the single tag
*KoronaClient::TagsApi* | [**get_tags**](docs/TagsApi.md#get_tags) | **GET** /accounts/{koronaAccountId}/tags | lists all tags
*KoronaClient::TagsApi* | [**update_tag**](docs/TagsApi.md#update_tag) | **PATCH** /accounts/{koronaAccountId}/tags/{tagId} | updates the single tag
*KoronaClient::TagsApi* | [**update_tags**](docs/TagsApi.md#update_tags) | **PATCH** /accounts/{koronaAccountId}/tags | updates a batch of tags
*KoronaClient::TicketCreationApi* | [**add_creation_task**](docs/TicketCreationApi.md#add_creation_task) | **POST** /accounts/{koronaAccountId}/ticketCreation | adds a creation task
*KoronaClient::TicketCreationApi* | [**get_creation_tasks**](docs/TicketCreationApi.md#get_creation_tasks) | **GET** /accounts/{koronaAccountId}/ticketCreation | creation tasks, personalization will always be empty for technical reasons
*KoronaClient::TicketingApi* | [**add_events**](docs/TicketingApi.md#add_events) | **POST** /accounts/{koronaAccountId}/events | adds a batch of new events
*KoronaClient::TicketingApi* | [**add_or_update_attendances**](docs/TicketingApi.md#add_or_update_attendances) | **POST** /accounts/{koronaAccountId}/attendance | updates/adds attendances
*KoronaClient::TicketingApi* | [**add_ticket_definitions**](docs/TicketingApi.md#add_ticket_definitions) | **POST** /accounts/{koronaAccountId}/ticketDefinitions | adds a batch of new ticket definitions
*KoronaClient::TicketingApi* | [**cancel_attendance**](docs/TicketingApi.md#cancel_attendance) | **DELETE** /accounts/{koronaAccountId}/attendance/{attendanceId} | cancel the attendance
*KoronaClient::TicketingApi* | [**delete_event**](docs/TicketingApi.md#delete_event) | **DELETE** /accounts/{koronaAccountId}/events/{eventId} | deletes the single event
*KoronaClient::TicketingApi* | [**delete_ticket_definition**](docs/TicketingApi.md#delete_ticket_definition) | **DELETE** /accounts/{koronaAccountId}/ticketDefinitions/{ticketDefinitionId} | deletes the single ticket definition
*KoronaClient::TicketingApi* | [**delete_ticket_definitions**](docs/TicketingApi.md#delete_ticket_definitions) | **DELETE** /accounts/{koronaAccountId}/ticketDefinitions | deletes a batch of ticket definitions
*KoronaClient::TicketingApi* | [**get_attendances**](docs/TicketingApi.md#get_attendances) | **GET** /accounts/{koronaAccountId}/attendance | lists all attendances
*KoronaClient::TicketingApi* | [**get_entry_gate**](docs/TicketingApi.md#get_entry_gate) | **GET** /accounts/{koronaAccountId}/entryGates/{entryGateId} | returns the single entry gate
*KoronaClient::TicketingApi* | [**get_entry_gates**](docs/TicketingApi.md#get_entry_gates) | **GET** /accounts/{koronaAccountId}/entryGates | lists all entry gates
*KoronaClient::TicketingApi* | [**get_event**](docs/TicketingApi.md#get_event) | **GET** /accounts/{koronaAccountId}/events/{eventId} | returns the single event
*KoronaClient::TicketingApi* | [**get_events**](docs/TicketingApi.md#get_events) | **GET** /accounts/{koronaAccountId}/events | lists all events
*KoronaClient::TicketingApi* | [**get_ticket_definition**](docs/TicketingApi.md#get_ticket_definition) | **GET** /accounts/{koronaAccountId}/ticketDefinitions/{ticketDefinitionId} | returns the single ticket definition
*KoronaClient::TicketingApi* | [**get_ticket_definitions**](docs/TicketingApi.md#get_ticket_definitions) | **GET** /accounts/{koronaAccountId}/ticketDefinitions | lists all ticket definitions
*KoronaClient::TicketingApi* | [**get_tickets**](docs/TicketingApi.md#get_tickets) | **GET** /accounts/{koronaAccountId}/tickets | lists all tickets
*KoronaClient::TicketingApi* | [**lock_ticket**](docs/TicketingApi.md#lock_ticket) | **DELETE** /accounts/{koronaAccountId}/tickets/{ticketNumber} | locks the single ticket
*KoronaClient::TicketingApi* | [**unlock_ticket**](docs/TicketingApi.md#unlock_ticket) | **POST** /accounts/{koronaAccountId}/tickets/{ticketNumber} | unlocks the single ticket
*KoronaClient::TicketingApi* | [**update_event**](docs/TicketingApi.md#update_event) | **PATCH** /accounts/{koronaAccountId}/events/{eventId} | updates the single event
*KoronaClient::TicketingApi* | [**update_events**](docs/TicketingApi.md#update_events) | **PATCH** /accounts/{koronaAccountId}/events | updates a batch of events
*KoronaClient::TicketingApi* | [**update_ticket**](docs/TicketingApi.md#update_ticket) | **PATCH** /accounts/{koronaAccountId}/tickets/{ticketNumber} | updates the single ticket
*KoronaClient::TicketingApi* | [**update_ticket_definitions**](docs/TicketingApi.md#update_ticket_definitions) | **PATCH** /accounts/{koronaAccountId}/ticketDefinitions | updates a batch of ticket definitions
*KoronaClient::TimeTrackingApi* | [**add_entities**](docs/TimeTrackingApi.md#add_entities) | **POST** /accounts/{koronaAccountId}/timeTrackingEntities | adds a batch of new time tracking entities
*KoronaClient::TimeTrackingApi* | [**add_entries**](docs/TimeTrackingApi.md#add_entries) | **POST** /accounts/{koronaAccountId}/timeTrackingEntries | adds a batch of new time tracking entries
*KoronaClient::TimeTrackingApi* | [**get_entities**](docs/TimeTrackingApi.md#get_entities) | **GET** /accounts/{koronaAccountId}/timeTrackingEntities | lists time tracking entities
*KoronaClient::TimeTrackingApi* | [**get_entries**](docs/TimeTrackingApi.md#get_entries) | **GET** /accounts/{koronaAccountId}/timeTrackingEntries | lists time tracking entries
*KoronaClient::TimeTrackingApi* | [**get_time_tracking_entity**](docs/TimeTrackingApi.md#get_time_tracking_entity) | **GET** /accounts/{koronaAccountId}/timeTrackingEntities/{timeTrackingEntityId} | returns a single time tracking entity
*KoronaClient::TimeTrackingApi* | [**get_time_tracking_entry**](docs/TimeTrackingApi.md#get_time_tracking_entry) | **GET** /accounts/{koronaAccountId}/timeTrackingEntries/{timeTrackingEntryId} | returns a single time tracking entry


## Documentation for Models

 - [KoronaClient::Account](docs/Account.md)
 - [KoronaClient::AccountSummary](docs/AccountSummary.md)
 - [KoronaClient::AccountTransaction](docs/AccountTransaction.md)
 - [KoronaClient::AddOrUpdateResult](docs/AddOrUpdateResult.md)
 - [KoronaClient::AdditionalInfo](docs/AdditionalInfo.md)
 - [KoronaClient::AdditionalReceiptInfoType](docs/AdditionalReceiptInfoType.md)
 - [KoronaClient::AddressInformation](docs/AddressInformation.md)
 - [KoronaClient::Admission](docs/Admission.md)
 - [KoronaClient::Amount](docs/Amount.md)
 - [KoronaClient::AmountCountData](docs/AmountCountData.md)
 - [KoronaClient::Assortment](docs/Assortment.md)
 - [KoronaClient::Attendance](docs/Attendance.md)
 - [KoronaClient::BadRequestError](docs/BadRequestError.md)
 - [KoronaClient::Capacity](docs/Capacity.md)
 - [KoronaClient::Cashier](docs/Cashier.md)
 - [KoronaClient::CashierSummary](docs/CashierSummary.md)
 - [KoronaClient::Category](docs/Category.md)
 - [KoronaClient::CloudSubscription](docs/CloudSubscription.md)
 - [KoronaClient::CommodityGroup](docs/CommodityGroup.md)
 - [KoronaClient::CommodityGroupSummary](docs/CommodityGroupSummary.md)
 - [KoronaClient::CompanyIdentification](docs/CompanyIdentification.md)
 - [KoronaClient::CreationTask](docs/CreationTask.md)
 - [KoronaClient::Currency](docs/Currency.md)
 - [KoronaClient::CurrencyDenomination](docs/CurrencyDenomination.md)
 - [KoronaClient::CurrencyExchangeRate](docs/CurrencyExchangeRate.md)
 - [KoronaClient::Customer](docs/Customer.md)
 - [KoronaClient::CustomerCard](docs/CustomerCard.md)
 - [KoronaClient::CustomerData](docs/CustomerData.md)
 - [KoronaClient::CustomerGroup](docs/CustomerGroup.md)
 - [KoronaClient::CustomerGroupSummary](docs/CustomerGroupSummary.md)
 - [KoronaClient::CustomerInformation](docs/CustomerInformation.md)
 - [KoronaClient::CustomerOrder](docs/CustomerOrder.md)
 - [KoronaClient::DayRating](docs/DayRating.md)
 - [KoronaClient::DayTimePeriod](docs/DayTimePeriod.md)
 - [KoronaClient::DeliveryNote](docs/DeliveryNote.md)
 - [KoronaClient::DeliveryNoteItem](docs/DeliveryNoteItem.md)
 - [KoronaClient::Deposit](docs/Deposit.md)
 - [KoronaClient::DeviceInformation](docs/DeviceInformation.md)
 - [KoronaClient::Discount](docs/Discount.md)
 - [KoronaClient::EconomicZone](docs/EconomicZone.md)
 - [KoronaClient::EndOfDayStatement](docs/EndOfDayStatement.md)
 - [KoronaClient::EndOfDayStatementSummary](docs/EndOfDayStatementSummary.md)
 - [KoronaClient::EntryGate](docs/EntryGate.md)
 - [KoronaClient::Event](docs/Event.md)
 - [KoronaClient::ExternalSystemCall](docs/ExternalSystemCall.md)
 - [KoronaClient::ForbiddenError](docs/ForbiddenError.md)
 - [KoronaClient::GeoLocation](docs/GeoLocation.md)
 - [KoronaClient::InfoText](docs/InfoText.md)
 - [KoronaClient::Interval](docs/Interval.md)
 - [KoronaClient::Inventory](docs/Inventory.md)
 - [KoronaClient::InventoryList](docs/InventoryList.md)
 - [KoronaClient::InventoryListItem](docs/InventoryListItem.md)
 - [KoronaClient::InventoryListItemStock](docs/InventoryListItemStock.md)
 - [KoronaClient::KoronaAccount](docs/KoronaAccount.md)
 - [KoronaClient::MediaUrl](docs/MediaUrl.md)
 - [KoronaClient::MethodNotAllowedError](docs/MethodNotAllowedError.md)
 - [KoronaClient::ModelReference](docs/ModelReference.md)
 - [KoronaClient::NotFoundError](docs/NotFoundError.md)
 - [KoronaClient::OrganizationalUnit](docs/OrganizationalUnit.md)
 - [KoronaClient::Payment](docs/Payment.md)
 - [KoronaClient::PaymentMethod](docs/PaymentMethod.md)
 - [KoronaClient::PaymentSummary](docs/PaymentSummary.md)
 - [KoronaClient::Period](docs/Period.md)
 - [KoronaClient::PeriodListTopSeller](docs/PeriodListTopSeller.md)
 - [KoronaClient::PeriodMapStringRevenueData](docs/PeriodMapStringRevenueData.md)
 - [KoronaClient::PeriodObject](docs/PeriodObject.md)
 - [KoronaClient::PeriodRevenueData](docs/PeriodRevenueData.md)
 - [KoronaClient::Pos](docs/Pos.md)
 - [KoronaClient::PriceGroup](docs/PriceGroup.md)
 - [KoronaClient::Product](docs/Product.md)
 - [KoronaClient::ProductCode](docs/ProductCode.md)
 - [KoronaClient::ProductDescription](docs/ProductDescription.md)
 - [KoronaClient::ProductPrice](docs/ProductPrice.md)
 - [KoronaClient::ProductStock](docs/ProductStock.md)
 - [KoronaClient::ProductSubproduct](docs/ProductSubproduct.md)
 - [KoronaClient::ProductSupplierPrice](docs/ProductSupplierPrice.md)
 - [KoronaClient::ProductTransferInvolvedPartyInformation](docs/ProductTransferInvolvedPartyInformation.md)
 - [KoronaClient::ProductTransferInvolvedPartyInformationData](docs/ProductTransferInvolvedPartyInformationData.md)
 - [KoronaClient::Rating](docs/Rating.md)
 - [KoronaClient::Receipt](docs/Receipt.md)
 - [KoronaClient::ReceiptItem](docs/ReceiptItem.md)
 - [KoronaClient::ResultList](docs/ResultList.md)
 - [KoronaClient::ResultListAccount](docs/ResultListAccount.md)
 - [KoronaClient::ResultListAdditionalReceiptInfoType](docs/ResultListAdditionalReceiptInfoType.md)
 - [KoronaClient::ResultListAssortment](docs/ResultListAssortment.md)
 - [KoronaClient::ResultListAttendance](docs/ResultListAttendance.md)
 - [KoronaClient::ResultListCashier](docs/ResultListCashier.md)
 - [KoronaClient::ResultListCommodityGroup](docs/ResultListCommodityGroup.md)
 - [KoronaClient::ResultListCreationTask](docs/ResultListCreationTask.md)
 - [KoronaClient::ResultListCurrency](docs/ResultListCurrency.md)
 - [KoronaClient::ResultListCustomer](docs/ResultListCustomer.md)
 - [KoronaClient::ResultListCustomerGroup](docs/ResultListCustomerGroup.md)
 - [KoronaClient::ResultListCustomerOrder](docs/ResultListCustomerOrder.md)
 - [KoronaClient::ResultListDayRating](docs/ResultListDayRating.md)
 - [KoronaClient::ResultListDeliveryNote](docs/ResultListDeliveryNote.md)
 - [KoronaClient::ResultListEconomicZone](docs/ResultListEconomicZone.md)
 - [KoronaClient::ResultListEndOfDayStatement](docs/ResultListEndOfDayStatement.md)
 - [KoronaClient::ResultListEntryGate](docs/ResultListEntryGate.md)
 - [KoronaClient::ResultListEvent](docs/ResultListEvent.md)
 - [KoronaClient::ResultListExternalSystemCall](docs/ResultListExternalSystemCall.md)
 - [KoronaClient::ResultListInfoText](docs/ResultListInfoText.md)
 - [KoronaClient::ResultListInventory](docs/ResultListInventory.md)
 - [KoronaClient::ResultListInventoryList](docs/ResultListInventoryList.md)
 - [KoronaClient::ResultListInventoryListItem](docs/ResultListInventoryListItem.md)
 - [KoronaClient::ResultListOrganizationalUnit](docs/ResultListOrganizationalUnit.md)
 - [KoronaClient::ResultListPaymentMethod](docs/ResultListPaymentMethod.md)
 - [KoronaClient::ResultListPos](docs/ResultListPos.md)
 - [KoronaClient::ResultListPriceGroup](docs/ResultListPriceGroup.md)
 - [KoronaClient::ResultListProduct](docs/ResultListProduct.md)
 - [KoronaClient::ResultListProductStock](docs/ResultListProductStock.md)
 - [KoronaClient::ResultListReceipt](docs/ResultListReceipt.md)
 - [KoronaClient::ResultListSalesTax](docs/ResultListSalesTax.md)
 - [KoronaClient::ResultListSector](docs/ResultListSector.md)
 - [KoronaClient::ResultListStockReceipt](docs/ResultListStockReceipt.md)
 - [KoronaClient::ResultListStockReceiptItem](docs/ResultListStockReceiptItem.md)
 - [KoronaClient::ResultListSupplier](docs/ResultListSupplier.md)
 - [KoronaClient::ResultListTag](docs/ResultListTag.md)
 - [KoronaClient::ResultListTicket](docs/ResultListTicket.md)
 - [KoronaClient::ResultListTicketDefinition](docs/ResultListTicketDefinition.md)
 - [KoronaClient::ResultListTimeTrackingEntity](docs/ResultListTimeTrackingEntity.md)
 - [KoronaClient::ResultListTimeTrackingEntry](docs/ResultListTimeTrackingEntry.md)
 - [KoronaClient::RevenueData](docs/RevenueData.md)
 - [KoronaClient::SalesTax](docs/SalesTax.md)
 - [KoronaClient::SalesTaxRate](docs/SalesTaxRate.md)
 - [KoronaClient::Sector](docs/Sector.md)
 - [KoronaClient::SectorRevenueAccountItem](docs/SectorRevenueAccountItem.md)
 - [KoronaClient::SectorSalesTaxItem](docs/SectorSalesTaxItem.md)
 - [KoronaClient::Signature](docs/Signature.md)
 - [KoronaClient::Statistic](docs/Statistic.md)
 - [KoronaClient::StatisticListTopSeller](docs/StatisticListTopSeller.md)
 - [KoronaClient::StatisticMapStringRevenueData](docs/StatisticMapStringRevenueData.md)
 - [KoronaClient::StatisticRevenueData](docs/StatisticRevenueData.md)
 - [KoronaClient::StockReceipt](docs/StockReceipt.md)
 - [KoronaClient::StockReceiptItem](docs/StockReceiptItem.md)
 - [KoronaClient::StockReceiptItemAmount](docs/StockReceiptItemAmount.md)
 - [KoronaClient::StockReceiptItemIdentification](docs/StockReceiptItemIdentification.md)
 - [KoronaClient::StockReceiptItemPurchasePrice](docs/StockReceiptItemPurchasePrice.md)
 - [KoronaClient::Supplier](docs/Supplier.md)
 - [KoronaClient::SupplierContact](docs/SupplierContact.md)
 - [KoronaClient::SupplierContactPerson](docs/SupplierContactPerson.md)
 - [KoronaClient::SupplierPaymentInformation](docs/SupplierPaymentInformation.md)
 - [KoronaClient::Tag](docs/Tag.md)
 - [KoronaClient::TaxPayment](docs/TaxPayment.md)
 - [KoronaClient::TaxSummary](docs/TaxSummary.md)
 - [KoronaClient::Ticket](docs/Ticket.md)
 - [KoronaClient::TicketDefinition](docs/TicketDefinition.md)
 - [KoronaClient::TicketPersonalization](docs/TicketPersonalization.md)
 - [KoronaClient::TimePeriod](docs/TimePeriod.md)
 - [KoronaClient::TimeTrackingEntity](docs/TimeTrackingEntity.md)
 - [KoronaClient::TimeTrackingEntry](docs/TimeTrackingEntry.md)
 - [KoronaClient::TooManyRequestsError](docs/TooManyRequestsError.md)
 - [KoronaClient::TopSeller](docs/TopSeller.md)
 - [KoronaClient::TotalPeriod](docs/TotalPeriod.md)
 - [KoronaClient::TotalPrice](docs/TotalPrice.md)
 - [KoronaClient::Validity](docs/Validity.md)
 - [KoronaClient::Weather](docs/Weather.md)


## Documentation for Authorization


### basicAuth

- **Type**: HTTP basic authentication

